#
# spec file for package busybox
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%ifarch x86_64 aarch64 i586
%bcond_without  ww3
%else
%bcond_with     ww3
%endif
%bcond_without  static

Name:           busybox
Version:        1.37.0
Release:        5.1
Summary:        Minimalist variant of UNIX utilities linked in a single executable
License:        GPL-2.0-or-later
URL:            https://www.busybox.net/
Source:         https://busybox.net/downloads/%{name}-%{version}.tar.bz2
Source2:        busybox.config
# Make sure busybox-static.config stays in sync with busybox.config -
# exception: SELinux commands - these do not build statically.
Source3:        busybox.config.static
Source4:        man.conf
Source5:        https://busybox.net/downloads/%{name}-%{version}.tar.bz2.sig
Source6:        https://busybox.net/~vda/vda_pubkey.gpg#/%{name}.keyring
Source7:        busybox.config.static.warewulf3
Patch0:         cpio-long-opt.patch
Patch1:         sendmail-ignore-F-option.patch
Patch2:         testsuite-gnu-echo.patch
# # PATCH-FIX-UPSTREAM shell: avoid segfault on ${0::0/0~09J} (CVE-2022-48174) https://git.busybox.net/busybox/commit/?id=d417193cf
# Patch3:         ash-fix-segfault-d417193cf.patch
Patch4:         udhcp6-install-path.patch
Patch5:         tc-no-TCA_CBQ.patch
# PATCH-FIX-UPSTREAM - Borrowed from Fedora - https://src.fedoraproject.org/rpms/busybox/blob/rawhide/f/busybox-1.37.0-fix-conditional-for-sha1_process_block64_shaNI.patch
Patch6:         busybox-1.37.0-fix-conditional-for-sha1_process_block64_shaNI.patch
# https://gitlab.alpinelinux.org/alpine/aports/-/raw/3.21-stable/main/busybox/0015-ping-make-ping-work-without-root-privileges.patch?ref_type=heads
Patch7:         busybox-1.37.0-make-ping-work-without-root-privileges.patch
#PATCH-FIX-UPSTREAM -  hexdump: fix regression with -n4 -e '"%u"' bug introduced in busybox 1.37.0 that broke kernel builds.
Patch8:         busybox-1.37.0-fix-regression-n2.patch
#PATCH-FIX-UPSTREAM - Fixes for hexdump and tests on big endian (S390) systems
Patch9:         busybox-1.37.0-hexdump-fix-regression-for-uint16-on-big-endian-syst.patch
Patch10:        busybox-1.37.0-od-make-B-test-little-endian-only-add-variant-for-bi.patch
Patch11:        busybox-1.37.0-hexdump-add-tests-for-x-handle-little-big-endian-pro.patch

# other patches
Patch100:       busybox.install.patch
BuildRequires:  glibc-devel-static
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libselinux)
# for test suite
BuildRequires:  zip
Provides:       useradd_or_adduser_dep
#in SLE12 hostname is part of the net-tools package
%if %{?suse_version} && %{?suse_version} <= 1315
BuildRequires:  net-tools
%else
BuildRequires:  hostname
%endif

%description
BusyBox combines tiny versions of many common UNIX utilities into a
single executable. It provides minimalist replacements for utilities
usually found in fileutils, shellutils, findutils, textutils, grep,
gzip, tar, and more. BusyBox provides a fairly complete POSIX
environment for small or embedded systems. The utilities in BusyBox
generally have fewer options than their GNU cousins. The options that
are included provide the expected functionality and behave much like
their GNU counterparts.
BusyBox is for emergency and special use cases. Replacing the standard
tools in a system is not supported. Some tools don't work out of the
box but need special configuration, like udhcpc, the dhcp client.

%package static
Summary:        Static linked version of Busybox, a compact UNIX utility collection

%description static
BusyBox combines tiny versions of many common UNIX utilities into a
single executable.

%package warewulf3
Summary:        Static version of Busybox - for building Warewulf3

%description warewulf3
This version of busybox is only for building Warewulf3
https://github.com/warewulf/warewulf3

%package testsuite
Summary:        Testsuite of busybox
Requires:       %{name} = %{version}
Requires:       zip

%description testsuite
Using this package you can test the busybox build on different kernels and glibc.
It needs to run with permission to the current directory, so either copy it away
as is or run as root:

cd %{_datadir}/busybox/testsuite
PATH=%{_datadir}/busybox:$PATH SKIP_KNOWN_BUGS=1 ./runtest

%prep
#SLE12 needs an empty line after autosetup for it to expand properly (bsc#1205420)
%autosetup -p1

find "(" -name CVS -o -name .cvsignore -o -name .svn -o -name .gitignore ")" \
	-exec rm -Rf {} +

%build
export KCONFIG_NOTIMESTAMP=KCONFIG_NOTIMESTAMP
export KBUILD_VERBOSE=1
export CFLAGS="%{optflags} -fPIC -fno-strict-aliasing -I/usr/include/tirpc"
export CC="gcc"
export HOSTCC=gcc
%if %{with static}
cat %{SOURCE3} %{SOURCE2} > .config
%make_build -e oldconfig
%make_build -e
mv busybox busybox-static
%endif

%if 0%{with ww3}
%make_build -e clean
cat %{SOURCE7} %{SOURCE3} %{SOURCE2} > .config
%make_build -e oldconfig
%make_build -e
mv busybox busybox-warewulf3
%make_build -e busybox.links
mv busybox.links busybox-warewulf3.links
%endif

%make_build -e clean
cp -a %{SOURCE2} .config
%make_build -e oldconfig
#make -e %{?_smp_mflags}
%make_build -e
%make_build -e doc busybox.links

%if 0%{?suse_version} >= 1550
for i in busybox.links %{?with_ww3:busybox-warewulf3.links}; do
    sed -i -e 's,^/\(s\?bin\)/,%{_prefix}/\1/,' $i
done
%endif

%install
install -d %{buildroot}/%{_bindir}
install -d %{buildroot}/%{_datadir}/busybox
install -m 0644 busybox.links %{buildroot}%{_datadir}/busybox
install applets/install.sh %{buildroot}%{_bindir}/busybox.install
install -m 0755 busybox %{buildroot}%{_bindir}
%if %{with static}
install -m 0755 busybox-static %{buildroot}%{_bindir}
%endif
install -d %{buildroot}%{_sysconfdir}
install -m 0644 %{SOURCE4} %{buildroot}%{_sysconfdir}/
install -d %{buildroot}%{_mandir}/man1
install -m 644 docs/busybox.1 %{buildroot}%{_mandir}/man1
%if %{with ww3}
install -m 0644 busybox-warewulf3.links %{buildroot}%{_datadir}/busybox
install -m 0755 busybox-warewulf3 %{buildroot}%{_bindir}
%endif
cp %{SOURCE2} %{buildroot}%{_datadir}/busybox/.config
ln -s %{_bindir}/busybox %{buildroot}%{_datadir}/busybox/busybox
cp -a testsuite %{buildroot}%{_datadir}/busybox/testsuite

%check
export KCONFIG_NOTIMESTAMP=KCONFIG_NOTIMESTAMP
export KBUILD_VERBOSE=1
export CFLAGS="%{optflags} -fPIC -fno-strict-aliasing -I/usr/include/tirpc"
export CC="gcc"
export HOSTCC=gcc
export SKIP_KNOWN_BUGS=1
export SKIP_INTERNET_TESTS=1
%make_build -e test

%files
%license LICENSE
%doc docs/mdev.txt
%config %{_sysconfdir}/man.conf
%{_mandir}/man1/busybox.1%{?ext_man}
%{_bindir}/busybox
%{_bindir}/busybox.install
%dir %{_datadir}/busybox
%{_datadir}/busybox/busybox.links

%files testsuite
%{_datadir}/busybox/busybox
%{_datadir}/busybox/.config
%{_datadir}/busybox/testsuite

%if %{with static}
%files static
%license LICENSE
%{_bindir}/busybox-static
%endif

%if %{with ww3}
%files warewulf3
%license LICENSE
%{_bindir}/busybox-warewulf3
%dir %{_datadir}/busybox
%{_datadir}/busybox/busybox-warewulf3.links
%endif

%changelog
* Thu Jul 17 2025 Radoslav Kolev <radoslav.kolev@suse.com>
- add placeholder variable and ignore applet logic to busybox.install
* Mon Jun 23 2025 Radoslav Kolev <radoslav.kolev@suse.com>
- enable halt, poweroff, reboot commands (bsc#1243201)
* Tue Apr 29 2025 Radoslav Kolev <radoslav.kolev@suse.com>
- fix regression in hexdump that broke kernel build:
  * busybox-1.37.0-fix-regression-n2.patch
- fix build/tests and hexdump on big endian systems (S390):
  * busybox-1.37.0-hexdump-fix-regression-for-uint16-on-big-endian-syst.patch
  * busybox-1.37.0-od-make-B-test-little-endian-only-add-variant-for-bi.patch
  * busybox-1.37.0-hexdump-add-tests-for-x-handle-little-big-endian-pro.patch
* Mon Mar 10 2025 Dirk Müller <dmueller@suse.com>
- add busybox-1.37.0-make-ping-work-without-root-privileges.patch
  (bsc#1239176)
* Mon Oct  7 2024 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add patch to fix build on non-x86* architectures:
  * busybox-1.37.0-fix-conditional-for-sha1_process_block64_shaNI.patch
* Fri Oct  4 2024 Thorsten Kukuk <kukuk@suse.com>
- Fix busybox.config again (got broken with 1.37.0 update)
- Cleanup spec file
* Sat Sep 28 2024 Matthias G. Eckermann <mge@suse.com>
- Update to 1.37.0
- remove unnecessary patch ash-fix-segfault-d417193cf.patch
- Update default config to match 1.37.0 expectations
- fix use-after-free in xasprintf (CVE-2023-42363, bsc#1217580)
- fix use-after-free in awk evaluate (CVE-2023-42364, bsc#1217584)
- fix use-after-free in awk copyvar (CVE-2023-42365, bsc#1217585)
* Thu Mar 14 2024 Thorsten Kukuk <kukuk@suse.com>
- tc-no-TCA_CBQ.patch: Disable TCA_CBQ code if kernel headers don't
  support them.
* Fri Dec  8 2023 Thorsten Kukuk <kukuk@suse.com>
- Install udhcpc and udhcpc6 into the same directory
  (udhcp6-install-path.patch)
- Fully enable udhcpc and document that this tool needs special
  configuration and does not work out of the box [bsc#1217883]
* Tue Aug 29 2023 Radoslav Kolev <radoslav.kolev@suse.com>
-  Add ash-fix-segfault-d417193cf.patch: fix stack overflow vulnerability
  in ash (CVE-2022-48174, bsc#1214538)
* Fri Jun  2 2023 Dirk Müller <dmueller@suse.com>
- update to 1.36.1:
  * fixes for line editing, detection of hardware sha1/sha256
    support, unzip
  (do not create suid/sgid files unless -K),
    shell (printf and sleep with no args, handing of SIGINT
    in sleep), ed.
* Fri Jan  6 2023 Radoslav Kolev <radoslav.kolev@suse.com>
- Update to version 1.36.0
  - awk: fix use after free (CVE-2022-30065)
  - various fixes for ash, bc, cut, fbset, kbuild, libbb, mkfs.vfat,
    mv, powertop, sed, sort, taskset, top, udhcpc6, unzip, vi, xxd
  - improvements in ash, cmp, crond, devmem, ed, fbset, fdisk, ls, xargs, pkill
  - new applets added: seedrng, tree, tsort
- Adjust busybox.config for new features
  - ash: enable sleep built-in
  - enable new applets: seedrng, tree, tsort
  - enable SHA hardware acceleration
  - try LOOP_CONFIGURE for losetup/loop mounts, but fall back to
    LOOP_SET_FD + LOOP_SET_STATUS if not supported
- drop e63d7cdf.patch (fix for CVE-2022-30065), included upstream
* Tue Dec 27 2022 Ludwig Nussel <lnussel@suse.com>
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Wed Nov 23 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add e63d7cdf.patch: awk: fix use after free (CVE-2022-30065,
  boo#1199744).
* Mon Nov 14 2022 Radoslav Kolev <radoslav.kolev@suse.com>
- Fix build under SLE-12
* Mon Oct 17 2022 Radoslav Kolev <radoslav.kolev@suse.com>
- Annotate CVEs already fixed in upstream, but not mentioned in .changes:
  * CVE-2014-9645 (bsc#914660):  strips of / in module names that can lead to loading unwanted modules
* Thu Jun 30 2022 Ludwig Nussel <lnussel@suse.de>
- prepare spec file for rpmbuild --build-in-place --noprep
- use bcond for static and ww3 subpackages
- fix verbose flag
* Fri Jun 10 2022 Marcos de Souza <mpdesouza@suse.com>
- Enable switch_root
  With this change virtme --force-initramfs works as expected.
* Wed Mar 30 2022 Marcos de Souza <mpdesouza@suse.com>
- Enable udhcpc
* Wed Mar 23 2022 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire hostname: the test suite wants to compare the output
  of 'hostname' against 'busybox hostname'. We should not rely
  hostname to be present in the build environment.
* Wed Jan 12 2022 Thorsten Kukuk <kukuk@suse.com>
- Update to 1.35.0
  - awk: fix printf %%%%, fix read beyond end of buffer
  - chrt: silence analyzer warning
  - libarchive: remove duplicate forward declaration
  - mount: "mount -o rw ...." should not fall back to RO mount
  - ps: fix -o pid=PID,args interpreting entire "PID,args" as header
  - tar: prevent malicious archives with long name sizes causing OOM
  - udhcpc6: fix udhcp_find_option to actually find DHCP6 options
  - xxd: fix -p -r
  - support for new optoins added to basename, cpio, date, find,
    mktemp, wget and others
- Adjust busybox.config for new features in find, date and cpio
* Thu Jan  6 2022 Radoslav Kolev <radoslav.kolev@suse.com>
- Annotate CVEs already fixed in upstream, but not mentioned in .changes:
  * CVE-2017-16544 (bsc#1069412): Insufficient sanitization of filenames when autocompleting
  * CVE-2015-9261 (bsc#1102912): huft_build misuses a pointer, causing segfaults
  * CVE-2016-2147 (bsc#970663): out of bounds write (heap) due to integer underflow in udhcpc
  * CVE-2016-2148 (bsc#970662): heap-based buffer overflow in OPTION_6RD parsing
  * CVE-2016-6301 (bsc#991940): NTP server denial of service flaw
  * CVE-2017-15873 (bsc#1064976): The get_next_block function in archival/libarchive/decompress_bunzip2.c has an Integer Overflow
  * CVE-2017-15874 (bsc#1064978): archival/libarchive/decompress_unlzma.c has an Integer Underflow
  * CVE-2019-5747 (bsc#1121428): out of bounds read in udhcp components
  * CVE-2021-42373, CVE-2021-42374, CVE-2021-42375, CVE-2021-42376,
    CVE-2021-42377, CVE-2021-42378, CVE-2021-42379, CVE-2021-42380,
    CVE-2021-42381, CVE-2021-42382, CVE-2021-42383, CVE-2021-42384,
    CVE-2021-42385, CVE-2021-42386 (bsc#1192869) : v1.34.0 bugfixes
  - CVE-2021-28831 (bsc#1184522): invalid free or segmentation fault via malformed gzip data
  - CVE-2018-20679 (bsc#1121426): out of bounds read in udhcp
  - CVE-2018-1000517 (bsc#1099260):  Heap-based buffer overflow in the retrieve_file_data()
  - CVE-2011-5325 (bsc#951562): tar directory traversal
  - CVE-2018-1000500 (bsc#1099263):  wget: Missing SSL certificate validation
* Sat Oct 30 2021 Stephan Kulow <coolo@suse.com>
- Disable crc32 to avoid conflict with perl-Archive-Zip
  (until some project really requires crc32)
* Wed Oct 27 2021 Egbert Eich <eich@suse.com>
- Build busybox-warewulf3 for i586 as well. This allowes to set up
  i586 nodes.
* Fri Oct 22 2021 Lukas Lansky <lukas.lansky@suse.com>
- Enable fdisk (jsc#CAR-16)
- Add testsuite-gnu-echo.patch: testing.sh to use GNU echo
* Thu Oct 21 2021 Stephan Kulow <coolo@suse.com>
- Remove the duplicated config entries and construct the snippets
  on the fly based on the main config. This way it's easier to
  keep track of what's different
* Thu Oct 21 2021 Stephan Kulow <coolo@suse.com>
- Update to 1.34.1:
  * build system: use SOURCE_DATE_EPOCH for timestamp if available
  * many bug fixes and new features
  * touch: make FEATURE_TOUCH_NODEREF unconditional
* Sat Oct  9 2021 Egbert Eich <eich@suse.com>
- Create separate 'Warewulf3' (https://github.com/warewulf/warewulf3)
  flavor of busybox with the
  additional setting:
  CONFIG_REBOOT=y
  CONFIG_SWITCH_ROOT=y
  CONFIG_CTTYHACK=y
  (bsc#1191514).
* Fri May  7 2021 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.33.1:
  * httpd: fix sendfile
  * ash: fix HISTFILE corruptio
  * ash: fix unset variable pattern expansion
  * traceroute: fix option parsing
  * gunzip: fix for archive corruption
- drop update_passwd_selinux_fix.patch, included upstream
- add upstream signing key and verify source signature
* Thu Jan 28 2021 Thorsten Kukuk <kukuk@suse.com>
- Update to version 1.33.0
  - many bug fixes and new features
- update_passwd_selinux_fix.patch upstream compile fix for SELinux
* Tue Jan  5 2021 Thorsten Kukuk <kukuk@suse.com>
- Update to version 1.32.1
  - fixes a case where in ash, "wait" never finishes.
* Tue Jan  5 2021 Thorsten Kukuk <kukuk@suse.com>
- sendmail-ignore-F-option.patch: ignore -F option as used by
  cron (workaround for [bbn#13426])
* Wed Dec  9 2020 Thorsten Kukuk <kukuk@suse.com>
- Don't require nogroup for adduser command, as this can lead to
  a dependency cycle with sysusers-tools.
* Mon Dec  7 2020 Thorsten Kukuk <kukuk@suse.com>
- cpio-long-opt.patch: add more long options to cpio for IBS/unrpm
* Fri Nov 20 2020 Ludwig Nussel <lnussel@suse.de>
- prepare usrmerge (boo#1029961)
* Tue Sep 29 2020 Thorsten Kukuk <kukuk@suse.com>
- Disable RPM builtin, did become pretty useless
- Disable popmaildir and mime utilities
* Fri Aug 21 2020 Thorsten Kukuk <kukuk@suse.com>
- Set CONFIG_FIRST_SYSTEM_ID to 101 as we use 100 already as fixed
  ID for a system account.
- Require group "nogroup" (used by adduser)
* Wed Aug 12 2020 Thorsten Kukuk <kukuk@suse.com>
- Enable SELinux for the dynamic version
* Wed Jul 22 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to busybox 1.32.0
  - many bugfixes and new features
  - Obsoletes busybox-no-stime.patch
* Wed Jul 22 2020 Thorsten Kukuk <kukuk@suse.com>
- Disable ftpget/ftpput, non-standard, ftp is outdated
- Disable run-init, we don't use that
- Disable cttyhack, we don't provide the calling tools
- Disable dnsd
* Sat Jul 11 2020 Thorsten Kukuk <kukuk@suse.com>
- Enable syslogd for containers
* Wed Jul  8 2020 Stephan Kulow <coolo@suse.com>
- Enable testsuite and package it for later rerun (for QA,
  jsc#CAR-15)
* Fri Apr 17 2020 Thorsten Kukuk <kukuk@suse.com>
- Re-add modutils
* Sat Mar 21 2020 Thorsten Kukuk <kukuk@suse.com>
- Set last ID to 65533, else nobody cannot be created
* Fri Mar 13 2020 Thorsten Kukuk <kukuk@suse.com>
- Merge config of default, -container and -static to be able to
  drop -container variant
* Sat Feb 22 2020 Thorsten Kukuk <kukuk@suse.com>
- Disable CONFIG_FEATURE_NSLOOKUP_BIG as it leads to incompatible
  nslookup behavior
* Mon Feb 10 2020 Thorsten Kukuk <kukuk@suse.com>
- Eanble FEATURE_TFTP_HPA_COMPAT and SH_MATH_BASE
* Sat Feb  8 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.31.1:
  + Bug fix release. 1.30.1 has fixes for dc, ash (PS1 expansion
    fix), hush, dpkg-deb, telnet and wget.
- Changes from version 1.31.0:
  + many bugfixes and new features.
- Add busybox-no-stime.patch: stime() has been deprecated in glibc
  2.31 and replaced with clock_settime().
* Wed Oct 23 2019 kukuk@suse.de
- Add man.conf to container variant
* Tue Sep 10 2019 Jan Engelhardt <jengelh@inai.de>
- Trim marketing from description.
* Thu Aug 22 2019 kukuk@suse.de
- Drop busybox-rpm-E.patch, not needed anymore
- Create new "container" subpackage with special stripped down
  version for container images (8MB instead of 15MB).
* Thu Jul 25 2019 kukuk@suse.de
- Provide "useradd_or_adduser_dep" for sysuser-shadow
* Fri Mar 29 2019 kukuk@suse.de
- Implement rpm -E %%_dbpath for kiwi (busybox-rpm-E.patch)
- Don't require /bin/sh, be self contained
* Thu Mar 28 2019 kukuk@suse.de
- update to 1.30.1
  * many bugfixes and new features
- obsolete busybox-1.18.3-libarchive.patch
- obsolete busybox-resource.patch
- Update busybox*.config
- Merge busybox.spec and busybox-static.spec and build the static
  binary as subpackage
* Wed Aug 22 2018 jjolly@suse.com
- Enabled functionality within busybox for warewulf compatibility
  * CONFIG_FEATURE_REMOTE_LOG
  * CONFIG_DEPMOD
  * CONFIG_TAC
* Fri Nov 10 2017 kukuk@suse.de
- Build against libtirpc in preparation of deprecating sunrpc from
  glibc
* Sun Jul  2 2017 astieger@suse.com
- update to 1.26.2:
  * many updates and fixes to individual tools
* Tue Nov  1 2016 astieger@suse.com
- update to 1.25.1:
  * fixes for hush, gunzip, ip route, ntpd
- includes changes from 1.25.0:
  * many added and expanded implementations of command options
- includes changes from 1.24.2:
  * fixes for build system (static build with glibc fixed),
    truncate, gunzip and unzip.
* Thu Mar  3 2016 olaf@aepfle.de
- Disable build timestamp
* Sun Jan  3 2016 p.drouand@gmail.com
- Update to version 1.24.1
  * for a full list of changes see http://www.busybox.net/news.html
- Refresh busybox.install.patch
* Mon Apr 20 2015 mpluskal@suse.com
- Update to 1.23.2
  * for a full list of changes see http://www.busybox.net/news.html
- Cleaned up spec file with spec-cleaner
- Refreshed patches
* Thu Oct  9 2014 olaf@aepfle.de
- Remove mkinitrd scripts
* Thu Sep  4 2014 andreas.stieger@gmx.de
- update to 1.22.1:
  Many updates and fixes for most included tools, see
  see http://www.busybox.net/news.html
- adjust busybox-resource.patch
* Thu Dec 12 2013 p.drouand@gmail.com
- Update to version 1.21.1
  + fixes for ntfs detection (big-endian fix)
  + xz decompression of concatenated streams
  + mdev acquired a [ENV=regex;] extension instead of undocumented
    subsystem match hack it used to have prior to 1.21.x.
- Changes from 1.21.0
  + udhcpc: gracefully handle packets with CHECKSUM_PARTIAL
  + ifupdown: improve compatibility with Debian
  + get_linux_version_code: don't fail on Linux version strings
    like "3.0-foo"
  + build system: fix build failure when only gunzip is selected
  + CONFIG_PID_FILE_PATH: new configuration option for pidfile paths
  + declare strings with ALIGN1, as appropriate
  + nanddump: use the right operator of logic AND
  + nanddump: skip bad blocks when instructed to do so
  + nanddump: invert the meaning of the -o parameter to match upstream
  + mount: fix -o user=foo mishandling, fix unc= generation, add prefixpath=
  + build system: fix build of kconfig on Darwin
  + tar: support -J, --xz explicit compression option
  + simplify copyright/license notice that appears in the binary
  + mdev: tell kernel that we didn't find the firmware
  + lineedit: fix Alt-D when cursor==0
  + lineedit: histfile can get emptied when CONFIG_FEATURE_EDITING_SAVE_ON_EXIT=y
  + build system: stop .eh_frame generation
  + build system: fix build failure when compressed help is selected, but bz2 compression is not
  + scripts/kconfig/mconf: work on systems w/o SIGWINCH
  + platform.h: disable ALIGNn macros for s390[x]
  + adduser: install to /usr, not /, like all other similar tools
  + ash: fix "read -s" + ^C. Closes 5504
  + ash: fix a bug in >${varexp} handling. Closes 5282
  + ash: implement export -n
  + ash: revert wrong "fix" for an apparent memory leak. Closes 5822
  + awk: fix FS assignment behavior. Closes 5108
  + awk: make -F STR interpret escape sequences. Closes 5126
  + brctl: fix build failure by s/strtotimeval/bb_strtotimeval/ (android has strtotimeval)
  + busybox: tweak help text and copyright year
  + decompress_uncompress: comment out debug printout on corrupted data
  + decompress_uncompress: move 'code' variable into loop - sole user
  + dhcpd: write lease file on exit
  + dpkg: fix creation of .list files (were empty since b768aeb). Closes 5324
  + du: document incompatibility with standard tool
  + examples/mdev_fat.conf: small addition
  + find: if DESKTOP=y, support -wholename (synonym for -path)
  + find: make -mindepth N -xdev correctly stop on mountpoints
  + ftpd: fix MDTM's month value. Closes 5336
  + ftpd: free allocated string on error path
  + getty: fix for NOCTTY killing us with SIGHUP
  + grep: fix grep -Fw not respecting the -w option. Closes 5792
  + ifconfig: do not accept "ifconfig eth0 up 1.2.3.4/17" (ip with mask). Closes 5786
  + libbb: correctness/size tweaks in signal-related helpers
  + lineedit: in !EDITING config, return -1 on fgets error
  + login: increase login name size limit from 32 to 64
  + lpr: don't send 0-byte print jobs (compat)
  + man: fix handling of gzipped manpages
  + mdev: add support for $DEVNAME and /dev/mdev.log debug aid
  + mdev: fix mode of dir1 in =dir1/dir2/file rule
  + mdev: remove undocumented subsystem/devname matching hack
  + mdev: when found, print major,minor into mdev.log
  + modprobe_small: make rmmod to NOT remove dependencies. Closes 5162
  + mount: do not pass "comment=ANYTHING" option to kernel. Closes 5240
  + mount: fix the wrongly stored fs creation time
  + mount: set up RO loop device if mount -o ro. Closes 4784
  + mount: support strictatime option. Closes 5240
  + ntpd: on time step, kill all outstanding replies from other peers
  + sed: fix handling of s/// which has empty matches
  + sed: fix zero chars match/replace
  + sha3: make size/speed optimization decision configurable
  + syslogd: do not segfault on parse error when using default config. Closes 5762
  + telnet: convert CR -> CR LF, not CR -> CR NUL when sending data to server
  + telnet: convert Enter -> CR LF in line mode too
  + tftpd: fix -u USER to work with chroot. Closes 5348
  + top/ps: argv0:"gdm-session-worker [pam/gdm-password]" == comm:"gdm-session-wor"
  + top: do not touch stdin if -b
  + top: fix "last CPU" parsing
  + top: implement scrolling up/down (_very_ useful)
  + udhcp[cd]: fix binding to network aliases. Closes 5432, 5438
  + udhcpc: make -O <numeric_opt> work. Closes 5402
  + udhcpc[6]: show select timeout in log
  + unzip: make options parsing more robust on getopt w/o gnu extensions
  + vi: do not set autoindent by default
  + vi: nuke FEATURE_VI_OPTIMIZE_CURSOR
  + vi: save/restore screen upon invocation
  + volume_id/ext: detect ext4 too
  + wget: correctly handle failure to -c (continue)
  + wget: make -c _not_ truncate the file
  + wget: reorder fread and poll: poll only if fread returns EAGAIN. Closes 5426
  + wget: try reading after poll timeout - stdio may have buffered data. Closes 5426
  + acpid: add missing lid switch definition
  + tar: fix 256-bit encoded number decoding
  + udhcpc[6]: allow discover_retries == 0 (infinite)
  + ash: fix a memory leak
  + sysctl: implement -q
  + powertop: fix error message
  + sha3sum: new applet
  + fbset: respect rgba configuration lines in fb.modes
  + fbsplash: support non-RGB565 pixels in 16-bit mode
  + flashcp: remove unused variable opts
  + mount: add unc option to CIFS mount (needed for Linux 3.4+)
  + nanddump: make dumping read-only partitions work
  + ps: use separate get_uptime() and make it work on non-linux too
  + declare strings with ALIGN1, as appropriate
  + udhcpc6: depend on ipv6
  + include sys/resource.h where needed
  + disable format security warnings
  + build system: use pkg-config to look up selinux libs
  + ifenslave: fix missing close paren
  + sed: allow 'w' cmd to use two address form
  + tar: implement --no-recursion
  + unzip: ignore chmod errors
  + brctl: fix description and usage
  + su: do not change to home dir unless -l
  + ntpd: fix incorrect m_status field in outgoing packets. Closes 5120
  + dmesg: handle multi-char log levels
  + klogd: handle multi-char log levels
  + syslogd: add option to log to Linux kernel printk buffer
  + syslogd: convert dummy functions to statics and get rid of IF_FEATURE_* checks
  + config: do not refer to HTTPS for wget
  + sendmail: use host rather than NIS domain name for HELO
  + mktemp: fix mktemp -u temp.XXXXXX returning garbage when TMPDIR is set
  + blkid: show filesystem when both label and UUID are missing, but type is known
  + volume_id: add exFAT detection
  + ln: support -T and -v
  + sed: support long opts and -iSFX
  + mkdir,rmdir: accept and ignore -v, --verbose
  + mv: accept but ignore -v
  + blkid: add type display for btrfs
  + blkid: add support for nilfs2
  + blkid: add type display for hfsplus
  + volume_id: display hfs[+] 128-bit UUID properly
  + volume_id: uuid_format small code shrink
  + volume_id: add squashfs detection
  + testsuite: some more awk tests related to conditions
  + modinfo: match more standard module fields and fix version field
  + inetd: fix build failure in Android
  + android: fix 'stat', ifdef S_TYPEIS* in coreutiles/stat.c
  + platform.h: Android tweaks: ioprio defines, BB_ADDITIONAL_PATH
  + android: some sensible defconfig changes
  + libbb: add missing_syscalls.c: for now, only Android syscalls
  + fbsplash: fix regression from e4fa7b7
  + adduser: make it accept "adduser USER GROUP" form
  + wget: add dummy --no-cache
  + testsuite: make mkfs.minix test not fail spuriously on big endian
  + refactor correct_password.c to avoid one if
* Sun Dec  9 2012 p.drouand@gmail.com
- Update to 1.20.2 (Bug fix release):
  * fix for variable expansion in redirection
  * fix for "pre-up" and "pre-down" handling
  * fixes for compressed man pages handling
  * important fix! due to misplaced s_mkfs_time field, ext4 driver
    couldn't mount our images
  * fix for getting uptime on non-Linux platforms
  * fix base-256 decoding
- Remove busybox-1.19.4-ext2fs_h.diff: fixed on upstream release
* Wed Aug  1 2012 lnussel@suse.de
- fix path in busybox.install (bnc#680153)
* Wed Jul 18 2012 aj@suse.de
- Add missing sys/resource include (glibc 2.16)
* Wed Jun  6 2012 seife+obs@b1-systems.com
- busybox-1.19.4-ext2fs_h.diff:
  more complete fix for latest ext2_fs.h breakage from busybox git,
  drop busybox-1.19.4-typedef_umode_t.patch
* Tue Apr 10 2012 ro@suse.de
- busybox-1.19.4-typedef_umode_t.patch:
  fix compile as umode_t is only defined with KERNEL and is
  used in header linux/linux/ext2_fs.h
* Tue Apr 10 2012 ro@suse.de
- update to 1.19.4
  - fix getty, mdev, modinfo and wget
- update to 1.19.3
  - fix chpasswd, crond, inetd, syslogd, tail, tftp
- update to 1.19.2
  - fix ash/hush, cttyhack, find, grep, less, patch, sed, top,
    uncompress
- update to 1.19.0:
  - countless fixes in all utility programs, please see
    http://www.busybox.net/ for details
- remove obsolete patches previously marked as upstreamed
* Fri Sep 30 2011 uli@suse.com
- cross-build fix: use %%__cc macro, set HOSTCC
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Sat Mar 12 2011 chris@computersalat.de
- update to 1.18.13
  see http://www.busybox.net/ for full changelog
- add upstream patches
  o buildsys.patch
  o cksum.patch
  o klogd.patch
  o menuconfig.patch
  o modutils24.patch
  o wget.patch
- rework libunarchive-array patch
  o -> libarchive patch
- remove .gitignore files
- added missing BusyBox.1 as S:1
- added export CFLAGS="{optflags} -fno-strict-aliasing"
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Wed Oct  6 2010 aj@suse.de
- Update to busybox 1.17.2:
  * obsoletes patches busybox.dmesg-size.patch, busybox-1.17.1-make.patch,
    busybox-buildfix.patch
  * see http://www.busybox.net/ for full changelog
* Mon Sep 20 2010 coolo@novell.com
- add backported fix for make 3.82
* Tue Aug  4 2009 aj@suse.de
- Fix build with updated kernel headers (busybox-buildfix.patch)
* Thu Dec 18 2008 sassmann@suse.de
- update to 1.12.3 bugfix release
  * has fixes for option parsing and line editing
* Tue Nov  4 2008 sassmann@suse.de
- updated config file to use a single config for
  both busybox and busybox-static
* Wed Oct 15 2008 sassmann@suse.de
- update to 1.12.1
  see http://www.busybox.net/ for full changelog
- removed patches included upstream
  * busybox-1.8.2-arping.patch
  * busybox-1.8.2-static
  * busybox-1.8.2-vi.patch
- refreshed patches
  * busybox.libunarchive-array.patch
  * busybox.dmesg-size.patch
- updated config file
  * removed awk math support and dc to get rid of libm
* Wed Sep  3 2008 hare@suse.de
- Call mkinitrd_setup during %%post and %%postun (bnc#413709)
* Fri Aug 22 2008 prusnak@suse.cz
- enabled SELinux support [Fate#303662]
* Wed Jul 23 2008 hare@suse.de
- Include mkinitrd scriptlets.
* Thu Jan 17 2008 sassmann@suse.de
- update to 1.8.2
  see http://www.busybox.net/ for full changelog
- added bugfixes
  * busybox-1.8.2-arping.patch
  * busybox-1.8.2-static
  * busybox-1.8.2-vi.patch
* Fri Nov 16 2007 olh@suse.de
- update to 1.8.1
  see http://www.busybox.net/ for full changelog
* Sun Jul 15 2007 olh@suse.de
- update to 1.6.1
  see http://www.busybox.net/ for full changelog
* Fri May 11 2007 olh@suse.de
- increase ash cmdline history size
  user kernel ringbuffer size for dmesg
* Mon May  7 2007 olh@suse.de
- gcc42 rejects out of bounds array access
* Sat Apr 28 2007 olh@suse.de
- update to 1.4.2
  reduces binary size after e2fsprogs removal
* Wed Dec  6 2006 trenn@suse.de
- move to 1.2.2 and enable nearly everything.
  Most important (awk,less,vi and much more)
  binary on i386 now has 732k
* Tue Aug  8 2006 ihno@suse.de
- update to busybox 1.2.1 final
  Bugfix release. Bugs fixed:
  lash: "var=value" works without export
  tar:  can extract git generated tarballs
  adduser: /etc/group is updated
  modprobe: look for modules.conf at the right place for 2.6 kernels
  all setuid and getgid calls are check return values in case
  somebody using per-process resource limits that prevent a user
  from having too many processes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 ihno@suse.de
- Update to busybox 1.1.0 final
* Wed Jan 11 2006 ihno@suse.de
- update to busybox 1.1.0-pre1
* Wed Nov 16 2005 dmueller@suse.de
- build against dietlibc unconditionally
* Thu May 12 2005 uli@suse.de
- use dietlibc on ARM
- uclibc config file needs to be fixed
* Fri Apr  1 2005 mmj@suse.de
- Correct function declaration
* Mon Jan 24 2005 nashif@suse.de
- Update to 1.00 final
* Tue Aug 17 2004 nashif@suse.de
- Update to 1.00-rc3
* Thu Aug  5 2004 nashif@suse.de
- Update to 1.00-rc2
* Wed Jul 21 2004 nashif@suse.de
- Update to 1.00-rc1
* Tue May 11 2004 nashif@suse.de
- Bug #39461 - Fixes netlink vulnerability
* Tue Apr 27 2004 mmj@suse.de
- Fix strict aliasing
* Mon Mar  1 2004 nashif@suse.de
- Update to 1.0 pre 8
* Wed Feb 11 2004 ro@suse.de
- hack to build it on amd64
* Tue Feb 10 2004 schwab@suse.de
- Fix building on ia64.
* Wed Feb  4 2004 kukuk@suse.de
- Remove wrong dietlibc requires
* Mon Feb  2 2004 hare@suse.de
- Fixed spec file to build on all archs.
* Fri Jan 30 2004 hare@suse.de
- Update to 1.00-pre5
- Patched dietlibc support to use a menuconfig option.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Wed Dec 10 2003 uli@suse.de
- build with dietlibc where available
* Mon Jun  2 2003 nashif@suse.de
- Set Autoreqprov:  on
* Thu May 29 2003 nashif@suse.de
- Updated with latest stable release incl. patches.
* Fri May 16 2003 nashif@suse.de
- Removed CVS files
* Sat Nov  2 2002 nashif@suse.de
- Update to version 0.60.5
- Unique patch names
* Mon Jun 10 2002 nashif@suse.de
- Update to version 0.60.3
* Mon Nov 26 2001 nashif@suse.de
- Update to version 0.60.2
- Major Changes:
  * msh was reworked
  * reworked hostname
  * Various bugfixes
* Fri Aug 24 2001 nashif@suse.de
- Update to version 0.60.1
- This is a relatively minor bug fixing release which fixes bugs
  in the following applets, among others: msh, sed, route, syslogd,
  ifconfig, lash
- Rewrite of tftp
* Sat Aug  4 2001 nashif@suse.de
- Update to version 0.60.0
* Thu Jul 12 2001 nashif@suse.de
- Update to version 0.52
* Wed Apr 11 2001 nashif@suse.de
- Update to version 0.51
* Fri Feb  9 2001 nashif@suse.de
- Fixed sync.c to compile
* Mon Feb  5 2001 nashif@suse.de
- Update to version 0.49
* Wed Dec 20 2000 uli@suse.de
- disabled insmod for all archs except IA32, ARM and SH
* Tue Dec 19 2000 nashif@suse.de
- Update to 0.48 (Fixes many bugs)
* Mon Nov 27 2000 nashif@suse.de
- Fixed pathes in install script
* Tue Nov  7 2000 nashif@suse.de
- Added EM_486 and OPEN_MAX fixes
* Wed Sep 27 2000 nashif@suse.de
- Update to 0.47
- Fix nfsmount.c
* Wed Aug 30 2000 nashif@suse.de
- Fix for axp
* Mon Aug 28 2000 nashif@suse.de
- Update to version 0.46
* Thu Jul  6 2000 nashif@suse.de
- Fix install script (Bug #3195)
* Tue May 23 2000 nashif@suse.de
- Initial Release (Version 0.43)
